# coding: utf-8

# flake8: noqa

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.7.0"

# import apis into sdk package
from equinix.services.fabricv4.api.cloud_routers_api import CloudRoutersApi
from equinix.services.fabricv4.api.connections_api import ConnectionsApi
from equinix.services.fabricv4.api.health_api import HealthApi
from equinix.services.fabricv4.api.marketplace_subscriptions_api import MarketplaceSubscriptionsApi
from equinix.services.fabricv4.api.metros_api import MetrosApi
from equinix.services.fabricv4.api.networks_api import NetworksApi
from equinix.services.fabricv4.api.ports_api import PortsApi
from equinix.services.fabricv4.api.precision_time_api import PrecisionTimeApi
from equinix.services.fabricv4.api.prices_api import PricesApi
from equinix.services.fabricv4.api.route_aggregation_rules_api import RouteAggregationRulesApi
from equinix.services.fabricv4.api.route_aggregations_api import RouteAggregationsApi
from equinix.services.fabricv4.api.route_filter_rules_api import RouteFilterRulesApi
from equinix.services.fabricv4.api.route_filters_api import RouteFiltersApi
from equinix.services.fabricv4.api.routing_protocols_api import RoutingProtocolsApi
from equinix.services.fabricv4.api.service_profiles_api import ServiceProfilesApi
from equinix.services.fabricv4.api.service_tokens_api import ServiceTokensApi
from equinix.services.fabricv4.api.statistics_api import StatisticsApi
from equinix.services.fabricv4.api.stream_subscriptions_api import StreamSubscriptionsApi
from equinix.services.fabricv4.api.streams_api import StreamsApi

# import ApiClient
from equinix.services.fabricv4.api_response import ApiResponse
from equinix.services.fabricv4.api_client import ApiClient
from equinix.services.fabricv4.configuration import Configuration
from equinix.services.fabricv4.exceptions import OpenApiException
from equinix.services.fabricv4.exceptions import ApiTypeError
from equinix.services.fabricv4.exceptions import ApiValueError
from equinix.services.fabricv4.exceptions import ApiKeyError
from equinix.services.fabricv4.exceptions import ApiAttributeError
from equinix.services.fabricv4.exceptions import ApiException

# import models into sdk package
from equinix.services.fabricv4.models.access_point import AccessPoint
from equinix.services.fabricv4.models.access_point_selector import AccessPointSelector
from equinix.services.fabricv4.models.access_point_selector_type import AccessPointSelectorType
from equinix.services.fabricv4.models.access_point_type import AccessPointType
from equinix.services.fabricv4.models.actions import Actions
from equinix.services.fabricv4.models.add_operation import AddOperation
from equinix.services.fabricv4.models.all_physical_ports_response import AllPhysicalPortsResponse
from equinix.services.fabricv4.models.all_ports_response import AllPortsResponse
from equinix.services.fabricv4.models.api_config import ApiConfig
from equinix.services.fabricv4.models.api_services import ApiServices
from equinix.services.fabricv4.models.asset import Asset
from equinix.services.fabricv4.models.authentication_key import AuthenticationKey
from equinix.services.fabricv4.models.bgp_action_data import BGPActionData
from equinix.services.fabricv4.models.bgp_action_request import BGPActionRequest
from equinix.services.fabricv4.models.bgp_action_states import BGPActionStates
from equinix.services.fabricv4.models.bgp_actions import BGPActions
from equinix.services.fabricv4.models.bgp_actions_bulk_data import BGPActionsBulkData
from equinix.services.fabricv4.models.bgp_connection_ipv4 import BGPConnectionIpv4
from equinix.services.fabricv4.models.bgp_connection_ipv6 import BGPConnectionIpv6
from equinix.services.fabricv4.models.bgp_connection_operation import BGPConnectionOperation
from equinix.services.fabricv4.models.bgp_connection_operation_operational_status import BGPConnectionOperationOperationalStatus
from equinix.services.fabricv4.models.bandwidth_utilization import BandwidthUtilization
from equinix.services.fabricv4.models.bandwidth_utilization_unit import BandwidthUtilizationUnit
from equinix.services.fabricv4.models.bulk_physical_port import BulkPhysicalPort
from equinix.services.fabricv4.models.bulk_port import BulkPort
from equinix.services.fabricv4.models.bulk_port_request import BulkPortRequest
from equinix.services.fabricv4.models.change import Change
from equinix.services.fabricv4.models.change_status import ChangeStatus
from equinix.services.fabricv4.models.change_type import ChangeType
from equinix.services.fabricv4.models.changelog import Changelog
from equinix.services.fabricv4.models.cloud_router import CloudRouter
from equinix.services.fabricv4.models.cloud_router_access_point_state import CloudRouterAccessPointState
from equinix.services.fabricv4.models.cloud_router_action_request import CloudRouterActionRequest
from equinix.services.fabricv4.models.cloud_router_action_response import CloudRouterActionResponse
from equinix.services.fabricv4.models.cloud_router_action_state import CloudRouterActionState
from equinix.services.fabricv4.models.cloud_router_action_type import CloudRouterActionType
from equinix.services.fabricv4.models.cloud_router_actions_search_expression import CloudRouterActionsSearchExpression
from equinix.services.fabricv4.models.cloud_router_actions_search_filter import CloudRouterActionsSearchFilter
from equinix.services.fabricv4.models.cloud_router_actions_search_filters import CloudRouterActionsSearchFilters
from equinix.services.fabricv4.models.cloud_router_actions_search_or_filter import CloudRouterActionsSearchOrFilter
from equinix.services.fabricv4.models.cloud_router_actions_search_request import CloudRouterActionsSearchRequest
from equinix.services.fabricv4.models.cloud_router_actions_search_response import CloudRouterActionsSearchResponse
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_by import CloudRouterActionsSearchSortBy
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_criteria import CloudRouterActionsSearchSortCriteria
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_direction import CloudRouterActionsSearchSortDirection
from equinix.services.fabricv4.models.cloud_router_change import CloudRouterChange
from equinix.services.fabricv4.models.cloud_router_change_operation import CloudRouterChangeOperation
from equinix.services.fabricv4.models.cloud_router_change_status import CloudRouterChangeStatus
from equinix.services.fabricv4.models.cloud_router_change_type import CloudRouterChangeType
from equinix.services.fabricv4.models.cloud_router_filter import CloudRouterFilter
from equinix.services.fabricv4.models.cloud_router_filters import CloudRouterFilters
from equinix.services.fabricv4.models.cloud_router_or_filter import CloudRouterOrFilter
from equinix.services.fabricv4.models.cloud_router_package import CloudRouterPackage
from equinix.services.fabricv4.models.cloud_router_package_type import CloudRouterPackageType
from equinix.services.fabricv4.models.cloud_router_post_request import CloudRouterPostRequest
from equinix.services.fabricv4.models.cloud_router_post_request_package import CloudRouterPostRequestPackage
from equinix.services.fabricv4.models.cloud_router_post_request_package_code import CloudRouterPostRequestPackageCode
from equinix.services.fabricv4.models.cloud_router_post_request_package_type import CloudRouterPostRequestPackageType
from equinix.services.fabricv4.models.cloud_router_post_request_type import CloudRouterPostRequestType
from equinix.services.fabricv4.models.cloud_router_search_request import CloudRouterSearchRequest
from equinix.services.fabricv4.models.cloud_router_simple_expression import CloudRouterSimpleExpression
from equinix.services.fabricv4.models.cloud_router_sort_by import CloudRouterSortBy
from equinix.services.fabricv4.models.cloud_router_sort_criteria import CloudRouterSortCriteria
from equinix.services.fabricv4.models.cloud_router_sort_direction import CloudRouterSortDirection
from equinix.services.fabricv4.models.code import Code
from equinix.services.fabricv4.models.connected_metro import ConnectedMetro
from equinix.services.fabricv4.models.connection import Connection
from equinix.services.fabricv4.models.connection_acceptance_data import ConnectionAcceptanceData
from equinix.services.fabricv4.models.connection_action import ConnectionAction
from equinix.services.fabricv4.models.connection_action_request import ConnectionActionRequest
from equinix.services.fabricv4.models.connection_change_operation import ConnectionChangeOperation
from equinix.services.fabricv4.models.connection_company_profile import ConnectionCompanyProfile
from equinix.services.fabricv4.models.connection_direction import ConnectionDirection
from equinix.services.fabricv4.models.connection_invitation import ConnectionInvitation
from equinix.services.fabricv4.models.connection_link import ConnectionLink
from equinix.services.fabricv4.models.connection_link_type import ConnectionLinkType
from equinix.services.fabricv4.models.connection_operation import ConnectionOperation
from equinix.services.fabricv4.models.connection_operation_operational_status import ConnectionOperationOperationalStatus
from equinix.services.fabricv4.models.connection_post_request import ConnectionPostRequest
from equinix.services.fabricv4.models.connection_priority import ConnectionPriority
from equinix.services.fabricv4.models.connection_redundancy import ConnectionRedundancy
from equinix.services.fabricv4.models.connection_response import ConnectionResponse
from equinix.services.fabricv4.models.connection_route_aggregation_data import ConnectionRouteAggregationData
from equinix.services.fabricv4.models.connection_route_aggregation_data_attachment_status import ConnectionRouteAggregationDataAttachmentStatus
from equinix.services.fabricv4.models.connection_route_aggregation_data_type import ConnectionRouteAggregationDataType
from equinix.services.fabricv4.models.connection_route_entry_filter import ConnectionRouteEntryFilter
from equinix.services.fabricv4.models.connection_route_entry_filters import ConnectionRouteEntryFilters
from equinix.services.fabricv4.models.connection_route_entry_or_filter import ConnectionRouteEntryOrFilter
from equinix.services.fabricv4.models.connection_route_entry_simple_expression import ConnectionRouteEntrySimpleExpression
from equinix.services.fabricv4.models.connection_route_entry_sort_by import ConnectionRouteEntrySortBy
from equinix.services.fabricv4.models.connection_route_entry_sort_direction import ConnectionRouteEntrySortDirection
from equinix.services.fabricv4.models.connection_route_filter_data import ConnectionRouteFilterData
from equinix.services.fabricv4.models.connection_route_filter_data_direction import ConnectionRouteFilterDataDirection
from equinix.services.fabricv4.models.connection_route_filter_data_type import ConnectionRouteFilterDataType
from equinix.services.fabricv4.models.connection_route_filters_base import ConnectionRouteFiltersBase
from equinix.services.fabricv4.models.connection_route_filters_base_direction import ConnectionRouteFiltersBaseDirection
from equinix.services.fabricv4.models.connection_route_search_request import ConnectionRouteSearchRequest
from equinix.services.fabricv4.models.connection_route_sort_criteria import ConnectionRouteSortCriteria
from equinix.services.fabricv4.models.connection_route_table_entry import ConnectionRouteTableEntry
from equinix.services.fabricv4.models.connection_route_table_entry_connection import ConnectionRouteTableEntryConnection
from equinix.services.fabricv4.models.connection_route_table_entry_search_response import ConnectionRouteTableEntrySearchResponse
from equinix.services.fabricv4.models.connection_route_table_entry_state import ConnectionRouteTableEntryState
from equinix.services.fabricv4.models.connection_routing_protocol_post_request import ConnectionRoutingProtocolPostRequest
from equinix.services.fabricv4.models.connection_search_response import ConnectionSearchResponse
from equinix.services.fabricv4.models.connection_side import ConnectionSide
from equinix.services.fabricv4.models.connection_side_additional_info import ConnectionSideAdditionalInfo
from equinix.services.fabricv4.models.connection_state import ConnectionState
from equinix.services.fabricv4.models.connection_type import ConnectionType
from equinix.services.fabricv4.models.connectivity_source import ConnectivitySource
from equinix.services.fabricv4.models.connectivity_source_type import ConnectivitySourceType
from equinix.services.fabricv4.models.custom_field import CustomField
from equinix.services.fabricv4.models.custom_field_data_type import CustomFieldDataType
from equinix.services.fabricv4.models.direct_connection_ipv4 import DirectConnectionIpv4
from equinix.services.fabricv4.models.direct_connection_ipv6 import DirectConnectionIpv6
from equinix.services.fabricv4.models.direction import Direction
from equinix.services.fabricv4.models.duration import Duration
from equinix.services.fabricv4.models.end_customer import EndCustomer
from equinix.services.fabricv4.models.equinix_status import EquinixStatus
from equinix.services.fabricv4.models.error import Error
from equinix.services.fabricv4.models.expression import Expression
from equinix.services.fabricv4.models.expression_operator import ExpressionOperator
from equinix.services.fabricv4.models.fabric_cloud_router_code import FabricCloudRouterCode
from equinix.services.fabricv4.models.fabric_cloud_router_packages import FabricCloudRouterPackages
from equinix.services.fabricv4.models.fabric_cloud_router_price import FabricCloudRouterPrice
from equinix.services.fabricv4.models.filter_body import FilterBody
from equinix.services.fabricv4.models.geo_coordinates import GeoCoordinates
from equinix.services.fabricv4.models.geo_scope_type import GeoScopeType
from equinix.services.fabricv4.models.get_all_connection_route_aggregations_response import GetAllConnectionRouteAggregationsResponse
from equinix.services.fabricv4.models.get_all_connection_route_filters_response import GetAllConnectionRouteFiltersResponse
from equinix.services.fabricv4.models.get_all_stream_asset_response import GetAllStreamAssetResponse
from equinix.services.fabricv4.models.get_all_stream_response import GetAllStreamResponse
from equinix.services.fabricv4.models.get_all_stream_subscription_response import GetAllStreamSubscriptionResponse
from equinix.services.fabricv4.models.get_response import GetResponse
from equinix.services.fabricv4.models.get_route_aggregation_get_connections_response import GetRouteAggregationGetConnectionsResponse
from equinix.services.fabricv4.models.get_route_aggregation_rules_response import GetRouteAggregationRulesResponse
from equinix.services.fabricv4.models.get_route_filter_get_connections_response import GetRouteFilterGetConnectionsResponse
from equinix.services.fabricv4.models.get_route_filter_rules_response import GetRouteFilterRulesResponse
from equinix.services.fabricv4.models.get_service_profiles_view_point_parameter import GetServiceProfilesViewPointParameter
from equinix.services.fabricv4.models.get_subscriptions_in_stream_response import GetSubscriptionsInStreamResponse
from equinix.services.fabricv4.models.get_time_services_package_by_code_package_code_parameter import GetTimeServicesPackageByCodePackageCodeParameter
from equinix.services.fabricv4.models.health_response import HealthResponse
from equinix.services.fabricv4.models.interface import Interface
from equinix.services.fabricv4.models.interface_type import InterfaceType
from equinix.services.fabricv4.models.internet_access import InternetAccess
from equinix.services.fabricv4.models.ip_block_price import IpBlockPrice
from equinix.services.fabricv4.models.ip_block_type import IpBlockType
from equinix.services.fabricv4.models.ipv4 import Ipv4
from equinix.services.fabricv4.models.json_patch_operation import JsonPatchOperation
from equinix.services.fabricv4.models.link import Link
from equinix.services.fabricv4.models.link_aggregation_group import LinkAggregationGroup
from equinix.services.fabricv4.models.link_protocol_connection import LinkProtocolConnection
from equinix.services.fabricv4.models.link_protocol_get_response import LinkProtocolGetResponse
from equinix.services.fabricv4.models.link_protocol_request_type import LinkProtocolRequestType
from equinix.services.fabricv4.models.link_protocol_response import LinkProtocolResponse
from equinix.services.fabricv4.models.link_protocol_service_token import LinkProtocolServiceToken
from equinix.services.fabricv4.models.link_protocol_state import LinkProtocolState
from equinix.services.fabricv4.models.link_protocol_type import LinkProtocolType
from equinix.services.fabricv4.models.marketing_info import MarketingInfo
from equinix.services.fabricv4.models.marketplace_subscription import MarketplaceSubscription
from equinix.services.fabricv4.models.marketplace_subscription_type import MarketplaceSubscriptionType
from equinix.services.fabricv4.models.md5 import Md5
from equinix.services.fabricv4.models.md5_type import Md5Type
from equinix.services.fabricv4.models.metal_interconnection import MetalInterconnection
from equinix.services.fabricv4.models.metric_interval import MetricInterval
from equinix.services.fabricv4.models.metrics import Metrics
from equinix.services.fabricv4.models.metro import Metro
from equinix.services.fabricv4.models.metro_error import MetroError
from equinix.services.fabricv4.models.metro_error_error_code import MetroErrorErrorCode
from equinix.services.fabricv4.models.metro_error_error_message import MetroErrorErrorMessage
from equinix.services.fabricv4.models.metro_response import MetroResponse
from equinix.services.fabricv4.models.network import Network
from equinix.services.fabricv4.models.network_change import NetworkChange
from equinix.services.fabricv4.models.network_change_operation import NetworkChangeOperation
from equinix.services.fabricv4.models.network_change_response import NetworkChangeResponse
from equinix.services.fabricv4.models.network_change_status import NetworkChangeStatus
from equinix.services.fabricv4.models.network_change_type import NetworkChangeType
from equinix.services.fabricv4.models.network_connections import NetworkConnections
from equinix.services.fabricv4.models.network_equinix_status import NetworkEquinixStatus
from equinix.services.fabricv4.models.network_filter import NetworkFilter
from equinix.services.fabricv4.models.network_filter_operator import NetworkFilterOperator
from equinix.services.fabricv4.models.network_operation import NetworkOperation
from equinix.services.fabricv4.models.network_post_request import NetworkPostRequest
from equinix.services.fabricv4.models.network_scope import NetworkScope
from equinix.services.fabricv4.models.network_search_field_name import NetworkSearchFieldName
from equinix.services.fabricv4.models.network_search_request import NetworkSearchRequest
from equinix.services.fabricv4.models.network_search_response import NetworkSearchResponse
from equinix.services.fabricv4.models.network_sort_by import NetworkSortBy
from equinix.services.fabricv4.models.network_sort_by_response import NetworkSortByResponse
from equinix.services.fabricv4.models.network_sort_criteria import NetworkSortCriteria
from equinix.services.fabricv4.models.network_sort_criteria_response import NetworkSortCriteriaResponse
from equinix.services.fabricv4.models.network_sort_direction import NetworkSortDirection
from equinix.services.fabricv4.models.network_sort_direction_response import NetworkSortDirectionResponse
from equinix.services.fabricv4.models.network_state import NetworkState
from equinix.services.fabricv4.models.network_type import NetworkType
from equinix.services.fabricv4.models.op_enum import OpEnum
from equinix.services.fabricv4.models.operation import Operation
from equinix.services.fabricv4.models.order import Order
from equinix.services.fabricv4.models.package import Package
from equinix.services.fabricv4.models.package_change_log import PackageChangeLog
from equinix.services.fabricv4.models.package_code import PackageCode
from equinix.services.fabricv4.models.package_response import PackageResponse
from equinix.services.fabricv4.models.package_type import PackageType
from equinix.services.fabricv4.models.pagination import Pagination
from equinix.services.fabricv4.models.pagination_request import PaginationRequest
from equinix.services.fabricv4.models.peering_type import PeeringType
from equinix.services.fabricv4.models.physical_port import PhysicalPort
from equinix.services.fabricv4.models.physical_port_settings import PhysicalPortSettings
from equinix.services.fabricv4.models.physical_port_type import PhysicalPortType
from equinix.services.fabricv4.models.port import Port
from equinix.services.fabricv4.models.port_additional_info import PortAdditionalInfo
from equinix.services.fabricv4.models.port_bmmr_type import PortBmmrType
from equinix.services.fabricv4.models.port_connectivity_source_type import PortConnectivitySourceType
from equinix.services.fabricv4.models.port_demarcation_point import PortDemarcationPoint
from equinix.services.fabricv4.models.port_device import PortDevice
from equinix.services.fabricv4.models.port_device_redundancy import PortDeviceRedundancy
from equinix.services.fabricv4.models.port_device_redundancy_priority import PortDeviceRedundancyPriority
from equinix.services.fabricv4.models.port_encapsulation import PortEncapsulation
from equinix.services.fabricv4.models.port_encapsulation_type import PortEncapsulationType
from equinix.services.fabricv4.models.port_expression import PortExpression
from equinix.services.fabricv4.models.port_interface import PortInterface
from equinix.services.fabricv4.models.port_lag import PortLag
from equinix.services.fabricv4.models.port_loa import PortLoa
from equinix.services.fabricv4.models.port_loa_type import PortLoaType
from equinix.services.fabricv4.models.port_notification import PortNotification
from equinix.services.fabricv4.models.port_notification_type import PortNotificationType
from equinix.services.fabricv4.models.port_operation import PortOperation
from equinix.services.fabricv4.models.port_operation_operational_status import PortOperationOperationalStatus
from equinix.services.fabricv4.models.port_order import PortOrder
from equinix.services.fabricv4.models.port_order_purchase_order import PortOrderPurchaseOrder
from equinix.services.fabricv4.models.port_order_purchase_order_selection_type import PortOrderPurchaseOrderSelectionType
from equinix.services.fabricv4.models.port_order_purchase_order_type import PortOrderPurchaseOrderType
from equinix.services.fabricv4.models.port_order_signature import PortOrderSignature
from equinix.services.fabricv4.models.port_order_signature_delegate import PortOrderSignatureDelegate
from equinix.services.fabricv4.models.port_order_signature_signatory import PortOrderSignatureSignatory
from equinix.services.fabricv4.models.port_physical_ports_type import PortPhysicalPortsType
from equinix.services.fabricv4.models.port_priority import PortPriority
from equinix.services.fabricv4.models.port_redundancy import PortRedundancy
from equinix.services.fabricv4.models.port_request import PortRequest
from equinix.services.fabricv4.models.port_search_field_name import PortSearchFieldName
from equinix.services.fabricv4.models.port_service_type import PortServiceType
from equinix.services.fabricv4.models.port_settings import PortSettings
from equinix.services.fabricv4.models.port_settings_package_type import PortSettingsPackageType
from equinix.services.fabricv4.models.port_settings_shared_port_product import PortSettingsSharedPortProduct
from equinix.services.fabricv4.models.port_sort_by import PortSortBy
from equinix.services.fabricv4.models.port_sort_criteria import PortSortCriteria
from equinix.services.fabricv4.models.port_sort_direction import PortSortDirection
from equinix.services.fabricv4.models.port_state import PortState
from equinix.services.fabricv4.models.port_tether import PortTether
from equinix.services.fabricv4.models.port_type import PortType
from equinix.services.fabricv4.models.port_v4_search_request import PortV4SearchRequest
from equinix.services.fabricv4.models.precision_time_change_operation import PrecisionTimeChangeOperation
from equinix.services.fabricv4.models.precision_time_change_operation_op import PrecisionTimeChangeOperationOp
from equinix.services.fabricv4.models.precision_time_change_operation_path import PrecisionTimeChangeOperationPath
from equinix.services.fabricv4.models.precision_time_order import PrecisionTimeOrder
from equinix.services.fabricv4.models.precision_time_package_request import PrecisionTimePackageRequest
from equinix.services.fabricv4.models.precision_time_package_request_code import PrecisionTimePackageRequestCode
from equinix.services.fabricv4.models.precision_time_package_response import PrecisionTimePackageResponse
from equinix.services.fabricv4.models.precision_time_package_response_type import PrecisionTimePackageResponseType
from equinix.services.fabricv4.models.precision_time_price import PrecisionTimePrice
from equinix.services.fabricv4.models.precision_time_service_connections_response import PrecisionTimeServiceConnectionsResponse
from equinix.services.fabricv4.models.precision_time_service_packages_response import PrecisionTimeServicePackagesResponse
from equinix.services.fabricv4.models.precision_time_service_request import PrecisionTimeServiceRequest
from equinix.services.fabricv4.models.precision_time_service_request_type import PrecisionTimeServiceRequestType
from equinix.services.fabricv4.models.precision_time_service_response import PrecisionTimeServiceResponse
from equinix.services.fabricv4.models.precision_time_service_response_state import PrecisionTimeServiceResponseState
from equinix.services.fabricv4.models.precision_time_service_response_type import PrecisionTimeServiceResponseType
from equinix.services.fabricv4.models.presence import Presence
from equinix.services.fabricv4.models.price import Price
from equinix.services.fabricv4.models.price_category import PriceCategory
from equinix.services.fabricv4.models.price_charge import PriceCharge
from equinix.services.fabricv4.models.price_charge_type import PriceChargeType
from equinix.services.fabricv4.models.price_error import PriceError
from equinix.services.fabricv4.models.price_error_additional_info import PriceErrorAdditionalInfo
from equinix.services.fabricv4.models.price_error_error_code import PriceErrorErrorCode
from equinix.services.fabricv4.models.price_error_error_message import PriceErrorErrorMessage
from equinix.services.fabricv4.models.price_location import PriceLocation
from equinix.services.fabricv4.models.price_search_response import PriceSearchResponse
from equinix.services.fabricv4.models.price_term_length import PriceTermLength
from equinix.services.fabricv4.models.process_step import ProcessStep
from equinix.services.fabricv4.models.product_type import ProductType
from equinix.services.fabricv4.models.project import Project
from equinix.services.fabricv4.models.provider_status import ProviderStatus
from equinix.services.fabricv4.models.ptp_advance_configuration import PtpAdvanceConfiguration
from equinix.services.fabricv4.models.ptp_advance_configuration_log_announce_interval import PtpAdvanceConfigurationLogAnnounceInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_delay_req_interval import PtpAdvanceConfigurationLogDelayReqInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_sync_interval import PtpAdvanceConfigurationLogSyncInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_time_scale import PtpAdvanceConfigurationTimeScale
from equinix.services.fabricv4.models.ptp_advance_configuration_transport_mode import PtpAdvanceConfigurationTransportMode
from equinix.services.fabricv4.models.query_direction import QueryDirection
from equinix.services.fabricv4.models.remove_operation import RemoveOperation
from equinix.services.fabricv4.models.replace_operation import ReplaceOperation
from equinix.services.fabricv4.models.route_aggregation_change_data import RouteAggregationChangeData
from equinix.services.fabricv4.models.route_aggregation_change_data_response import RouteAggregationChangeDataResponse
from equinix.services.fabricv4.models.route_aggregation_connections_data import RouteAggregationConnectionsData
from equinix.services.fabricv4.models.route_aggregation_rule_state import RouteAggregationRuleState
from equinix.services.fabricv4.models.route_aggregation_rules_base import RouteAggregationRulesBase
from equinix.services.fabricv4.models.route_aggregation_rules_change import RouteAggregationRulesChange
from equinix.services.fabricv4.models.route_aggregation_rules_change_data import RouteAggregationRulesChangeData
from equinix.services.fabricv4.models.route_aggregation_rules_change_data_response import RouteAggregationRulesChangeDataResponse
from equinix.services.fabricv4.models.route_aggregation_rules_change_operation import RouteAggregationRulesChangeOperation
from equinix.services.fabricv4.models.route_aggregation_rules_change_type import RouteAggregationRulesChangeType
from equinix.services.fabricv4.models.route_aggregation_rules_data import RouteAggregationRulesData
from equinix.services.fabricv4.models.route_aggregation_rules_data_type import RouteAggregationRulesDataType
from equinix.services.fabricv4.models.route_aggregation_rules_patch_request_item import RouteAggregationRulesPatchRequestItem
from equinix.services.fabricv4.models.route_aggregation_rules_post_request import RouteAggregationRulesPostRequest
from equinix.services.fabricv4.models.route_aggregation_sort_item import RouteAggregationSortItem
from equinix.services.fabricv4.models.route_aggregation_sort_item_property import RouteAggregationSortItemProperty
from equinix.services.fabricv4.models.route_aggregation_state import RouteAggregationState
from equinix.services.fabricv4.models.route_aggregations_base import RouteAggregationsBase
from equinix.services.fabricv4.models.route_aggregations_base_type import RouteAggregationsBaseType
from equinix.services.fabricv4.models.route_aggregations_change import RouteAggregationsChange
from equinix.services.fabricv4.models.route_aggregations_change_operation import RouteAggregationsChangeOperation
from equinix.services.fabricv4.models.route_aggregations_change_type import RouteAggregationsChangeType
from equinix.services.fabricv4.models.route_aggregations_data import RouteAggregationsData
from equinix.services.fabricv4.models.route_aggregations_data_project import RouteAggregationsDataProject
from equinix.services.fabricv4.models.route_aggregations_patch_request_item import RouteAggregationsPatchRequestItem
from equinix.services.fabricv4.models.route_aggregations_search_base import RouteAggregationsSearchBase
from equinix.services.fabricv4.models.route_aggregations_search_base_filter import RouteAggregationsSearchBaseFilter
from equinix.services.fabricv4.models.route_aggregations_search_filter_item import RouteAggregationsSearchFilterItem
from equinix.services.fabricv4.models.route_aggregations_search_response import RouteAggregationsSearchResponse
from equinix.services.fabricv4.models.route_filter_change_data import RouteFilterChangeData
from equinix.services.fabricv4.models.route_filter_change_data_response import RouteFilterChangeDataResponse
from equinix.services.fabricv4.models.route_filter_connections_data import RouteFilterConnectionsData
from equinix.services.fabricv4.models.route_filter_rule_state import RouteFilterRuleState
from equinix.services.fabricv4.models.route_filter_rules_base import RouteFilterRulesBase
from equinix.services.fabricv4.models.route_filter_rules_change import RouteFilterRulesChange
from equinix.services.fabricv4.models.route_filter_rules_change_data import RouteFilterRulesChangeData
from equinix.services.fabricv4.models.route_filter_rules_change_data_response import RouteFilterRulesChangeDataResponse
from equinix.services.fabricv4.models.route_filter_rules_change_operation import RouteFilterRulesChangeOperation
from equinix.services.fabricv4.models.route_filter_rules_change_type import RouteFilterRulesChangeType
from equinix.services.fabricv4.models.route_filter_rules_data import RouteFilterRulesData
from equinix.services.fabricv4.models.route_filter_rules_data_action import RouteFilterRulesDataAction
from equinix.services.fabricv4.models.route_filter_rules_data_type import RouteFilterRulesDataType
from equinix.services.fabricv4.models.route_filter_rules_patch_request_item import RouteFilterRulesPatchRequestItem
from equinix.services.fabricv4.models.route_filter_rules_post_request import RouteFilterRulesPostRequest
from equinix.services.fabricv4.models.route_filter_state import RouteFilterState
from equinix.services.fabricv4.models.route_filters_base import RouteFiltersBase
from equinix.services.fabricv4.models.route_filters_base_type import RouteFiltersBaseType
from equinix.services.fabricv4.models.route_filters_change import RouteFiltersChange
from equinix.services.fabricv4.models.route_filters_change_operation import RouteFiltersChangeOperation
from equinix.services.fabricv4.models.route_filters_change_type import RouteFiltersChangeType
from equinix.services.fabricv4.models.route_filters_data import RouteFiltersData
from equinix.services.fabricv4.models.route_filters_data_not_matched_rule_action import RouteFiltersDataNotMatchedRuleAction
from equinix.services.fabricv4.models.route_filters_data_project import RouteFiltersDataProject
from equinix.services.fabricv4.models.route_filters_patch_request_item import RouteFiltersPatchRequestItem
from equinix.services.fabricv4.models.route_filters_search_base import RouteFiltersSearchBase
from equinix.services.fabricv4.models.route_filters_search_base_filter import RouteFiltersSearchBaseFilter
from equinix.services.fabricv4.models.route_filters_search_filter_item import RouteFiltersSearchFilterItem
from equinix.services.fabricv4.models.route_filters_search_filter_item_property import RouteFiltersSearchFilterItemProperty
from equinix.services.fabricv4.models.route_filters_search_response import RouteFiltersSearchResponse
from equinix.services.fabricv4.models.route_table_entry import RouteTableEntry
from equinix.services.fabricv4.models.route_table_entry_filter import RouteTableEntryFilter
from equinix.services.fabricv4.models.route_table_entry_filters import RouteTableEntryFilters
from equinix.services.fabricv4.models.route_table_entry_or_filter import RouteTableEntryOrFilter
from equinix.services.fabricv4.models.route_table_entry_protocol_type import RouteTableEntryProtocolType
from equinix.services.fabricv4.models.route_table_entry_search_request import RouteTableEntrySearchRequest
from equinix.services.fabricv4.models.route_table_entry_search_response import RouteTableEntrySearchResponse
from equinix.services.fabricv4.models.route_table_entry_simple_expression import RouteTableEntrySimpleExpression
from equinix.services.fabricv4.models.route_table_entry_sort_by import RouteTableEntrySortBy
from equinix.services.fabricv4.models.route_table_entry_sort_criteria import RouteTableEntrySortCriteria
from equinix.services.fabricv4.models.route_table_entry_sort_direction import RouteTableEntrySortDirection
from equinix.services.fabricv4.models.route_table_entry_state import RouteTableEntryState
from equinix.services.fabricv4.models.route_table_entry_type import RouteTableEntryType
from equinix.services.fabricv4.models.router_actions_connection import RouterActionsConnection
from equinix.services.fabricv4.models.router_package_code import RouterPackageCode
from equinix.services.fabricv4.models.routing_protocol_bfd import RoutingProtocolBFD
from equinix.services.fabricv4.models.routing_protocol_bgp_data import RoutingProtocolBGPData
from equinix.services.fabricv4.models.routing_protocol_bgp_data_state import RoutingProtocolBGPDataState
from equinix.services.fabricv4.models.routing_protocol_bgp_type import RoutingProtocolBGPType
from equinix.services.fabricv4.models.routing_protocol_bgp_type_type import RoutingProtocolBGPTypeType
from equinix.services.fabricv4.models.routing_protocol_base import RoutingProtocolBase
from equinix.services.fabricv4.models.routing_protocol_change import RoutingProtocolChange
from equinix.services.fabricv4.models.routing_protocol_change_data import RoutingProtocolChangeData
from equinix.services.fabricv4.models.routing_protocol_change_data_response import RoutingProtocolChangeDataResponse
from equinix.services.fabricv4.models.routing_protocol_change_operation import RoutingProtocolChangeOperation
from equinix.services.fabricv4.models.routing_protocol_change_operation_op import RoutingProtocolChangeOperationOp
from equinix.services.fabricv4.models.routing_protocol_change_type import RoutingProtocolChangeType
from equinix.services.fabricv4.models.routing_protocol_data import RoutingProtocolData
from equinix.services.fabricv4.models.routing_protocol_direct_data import RoutingProtocolDirectData
from equinix.services.fabricv4.models.routing_protocol_direct_type import RoutingProtocolDirectType
from equinix.services.fabricv4.models.routing_protocol_direct_type_type import RoutingProtocolDirectTypeType
from equinix.services.fabricv4.models.routing_protocol_operation import RoutingProtocolOperation
from equinix.services.fabricv4.models.search_expression import SearchExpression
from equinix.services.fabricv4.models.search_field_name import SearchFieldName
from equinix.services.fabricv4.models.search_request import SearchRequest
from equinix.services.fabricv4.models.search_response import SearchResponse
from equinix.services.fabricv4.models.service_metro import ServiceMetro
from equinix.services.fabricv4.models.service_metros import ServiceMetros
from equinix.services.fabricv4.models.service_profile import ServiceProfile
from equinix.services.fabricv4.models.service_profile_access_point_colo import ServiceProfileAccessPointCOLO
from equinix.services.fabricv4.models.service_profile_access_point_colo_type import ServiceProfileAccessPointCOLOType
from equinix.services.fabricv4.models.service_profile_access_point_type import ServiceProfileAccessPointType
from equinix.services.fabricv4.models.service_profile_access_point_type_colo import ServiceProfileAccessPointTypeCOLO
from equinix.services.fabricv4.models.service_profile_access_point_type_enum import ServiceProfileAccessPointTypeEnum
from equinix.services.fabricv4.models.service_profile_access_point_type_vd import ServiceProfileAccessPointTypeVD
from equinix.services.fabricv4.models.service_profile_access_point_vd import ServiceProfileAccessPointVD
from equinix.services.fabricv4.models.service_profile_access_point_vd_type import ServiceProfileAccessPointVDType
from equinix.services.fabricv4.models.service_profile_and_filter import ServiceProfileAndFilter
from equinix.services.fabricv4.models.service_profile_filter import ServiceProfileFilter
from equinix.services.fabricv4.models.service_profile_link_protocol_config import ServiceProfileLinkProtocolConfig
from equinix.services.fabricv4.models.service_profile_link_protocol_config_encapsulation import ServiceProfileLinkProtocolConfigEncapsulation
from equinix.services.fabricv4.models.service_profile_link_protocol_config_encapsulation_strategy import ServiceProfileLinkProtocolConfigEncapsulationStrategy
from equinix.services.fabricv4.models.service_profile_metadata import ServiceProfileMetadata
from equinix.services.fabricv4.models.service_profile_request import ServiceProfileRequest
from equinix.services.fabricv4.models.service_profile_search_request import ServiceProfileSearchRequest
from equinix.services.fabricv4.models.service_profile_simple_expression import ServiceProfileSimpleExpression
from equinix.services.fabricv4.models.service_profile_sort_by import ServiceProfileSortBy
from equinix.services.fabricv4.models.service_profile_sort_criteria import ServiceProfileSortCriteria
from equinix.services.fabricv4.models.service_profile_sort_direction import ServiceProfileSortDirection
from equinix.services.fabricv4.models.service_profile_state_enum import ServiceProfileStateEnum
from equinix.services.fabricv4.models.service_profile_type_enum import ServiceProfileTypeEnum
from equinix.services.fabricv4.models.service_profile_visibility_enum import ServiceProfileVisibilityEnum
from equinix.services.fabricv4.models.service_profiles import ServiceProfiles
from equinix.services.fabricv4.models.service_search_response import ServiceSearchResponse
from equinix.services.fabricv4.models.service_token import ServiceToken
from equinix.services.fabricv4.models.service_token_action_request import ServiceTokenActionRequest
from equinix.services.fabricv4.models.service_token_actions import ServiceTokenActions
from equinix.services.fabricv4.models.service_token_change_operation import ServiceTokenChangeOperation
from equinix.services.fabricv4.models.service_token_connection import ServiceTokenConnection
from equinix.services.fabricv4.models.service_token_connection_type import ServiceTokenConnectionType
from equinix.services.fabricv4.models.service_token_search_expression import ServiceTokenSearchExpression
from equinix.services.fabricv4.models.service_token_search_expression_operator import ServiceTokenSearchExpressionOperator
from equinix.services.fabricv4.models.service_token_search_field_name import ServiceTokenSearchFieldName
from equinix.services.fabricv4.models.service_token_search_request import ServiceTokenSearchRequest
from equinix.services.fabricv4.models.service_token_side import ServiceTokenSide
from equinix.services.fabricv4.models.service_token_state import ServiceTokenState
from equinix.services.fabricv4.models.service_token_type import ServiceTokenType
from equinix.services.fabricv4.models.service_tokens import ServiceTokens
from equinix.services.fabricv4.models.simplified_account import SimplifiedAccount
from equinix.services.fabricv4.models.simplified_link_protocol import SimplifiedLinkProtocol
from equinix.services.fabricv4.models.simplified_location import SimplifiedLocation
from equinix.services.fabricv4.models.simplified_location_without_ibx import SimplifiedLocationWithoutIBX
from equinix.services.fabricv4.models.simplified_metadata_entity import SimplifiedMetadataEntity
from equinix.services.fabricv4.models.simplified_network import SimplifiedNetwork
from equinix.services.fabricv4.models.simplified_network_change import SimplifiedNetworkChange
from equinix.services.fabricv4.models.simplified_notification import SimplifiedNotification
from equinix.services.fabricv4.models.simplified_notification_type import SimplifiedNotificationType
from equinix.services.fabricv4.models.simplified_port import SimplifiedPort
from equinix.services.fabricv4.models.simplified_service_profile import SimplifiedServiceProfile
from equinix.services.fabricv4.models.simplified_token_network import SimplifiedTokenNetwork
from equinix.services.fabricv4.models.simplified_token_network_scope import SimplifiedTokenNetworkScope
from equinix.services.fabricv4.models.simplified_token_network_type import SimplifiedTokenNetworkType
from equinix.services.fabricv4.models.simplified_virtual_device import SimplifiedVirtualDevice
from equinix.services.fabricv4.models.simplified_virtual_device_type import SimplifiedVirtualDeviceType
from equinix.services.fabricv4.models.sort import Sort
from equinix.services.fabricv4.models.sort_by import SortBy
from equinix.services.fabricv4.models.sort_criteria import SortCriteria
from equinix.services.fabricv4.models.sort_criteria_response import SortCriteriaResponse
from equinix.services.fabricv4.models.sort_direction import SortDirection
from equinix.services.fabricv4.models.sort_item import SortItem
from equinix.services.fabricv4.models.sort_item_direction import SortItemDirection
from equinix.services.fabricv4.models.sort_item_property import SortItemProperty
from equinix.services.fabricv4.models.statistics import Statistics
from equinix.services.fabricv4.models.statistics_view_point import StatisticsViewPoint
from equinix.services.fabricv4.models.stream import Stream
from equinix.services.fabricv4.models.stream_asset import StreamAsset
from equinix.services.fabricv4.models.stream_asset_attachment_status import StreamAssetAttachmentStatus
from equinix.services.fabricv4.models.stream_asset_filter import StreamAssetFilter
from equinix.services.fabricv4.models.stream_asset_filters import StreamAssetFilters
from equinix.services.fabricv4.models.stream_asset_or_filter import StreamAssetOrFilter
from equinix.services.fabricv4.models.stream_asset_put_request import StreamAssetPutRequest
from equinix.services.fabricv4.models.stream_asset_search_request import StreamAssetSearchRequest
from equinix.services.fabricv4.models.stream_asset_simple_expression import StreamAssetSimpleExpression
from equinix.services.fabricv4.models.stream_asset_sort_by import StreamAssetSortBy
from equinix.services.fabricv4.models.stream_asset_sort_criteria import StreamAssetSortCriteria
from equinix.services.fabricv4.models.stream_asset_sort_direction import StreamAssetSortDirection
from equinix.services.fabricv4.models.stream_asset_type import StreamAssetType
from equinix.services.fabricv4.models.stream_filter import StreamFilter
from equinix.services.fabricv4.models.stream_filter_or_filter import StreamFilterOrFilter
from equinix.services.fabricv4.models.stream_filter_simple_expression import StreamFilterSimpleExpression
from equinix.services.fabricv4.models.stream_get_subscriptions import StreamGetSubscriptions
from equinix.services.fabricv4.models.stream_get_subscriptions_type import StreamGetSubscriptionsType
from equinix.services.fabricv4.models.stream_post_request import StreamPostRequest
from equinix.services.fabricv4.models.stream_post_request_type import StreamPostRequestType
from equinix.services.fabricv4.models.stream_put_request import StreamPutRequest
from equinix.services.fabricv4.models.stream_subscription import StreamSubscription
from equinix.services.fabricv4.models.stream_subscription_filter import StreamSubscriptionFilter
from equinix.services.fabricv4.models.stream_subscription_post_request import StreamSubscriptionPostRequest
from equinix.services.fabricv4.models.stream_subscription_post_request_type import StreamSubscriptionPostRequestType
from equinix.services.fabricv4.models.stream_subscription_put_request import StreamSubscriptionPutRequest
from equinix.services.fabricv4.models.stream_subscription_selector import StreamSubscriptionSelector
from equinix.services.fabricv4.models.stream_subscription_sink import StreamSubscriptionSink
from equinix.services.fabricv4.models.stream_subscription_sink_credential import StreamSubscriptionSinkCredential
from equinix.services.fabricv4.models.stream_subscription_sink_credential_type import StreamSubscriptionSinkCredentialType
from equinix.services.fabricv4.models.stream_subscription_sink_setting import StreamSubscriptionSinkSetting
from equinix.services.fabricv4.models.stream_subscription_sink_type import StreamSubscriptionSinkType
from equinix.services.fabricv4.models.stream_subscription_state import StreamSubscriptionState
from equinix.services.fabricv4.models.stream_subscription_type import StreamSubscriptionType
from equinix.services.fabricv4.models.stream_target import StreamTarget
from equinix.services.fabricv4.models.sub_interface import SubInterface
from equinix.services.fabricv4.models.subscription_asset import SubscriptionAsset
from equinix.services.fabricv4.models.subscription_entitlement_response import SubscriptionEntitlementResponse
from equinix.services.fabricv4.models.subscription_response import SubscriptionResponse
from equinix.services.fabricv4.models.subscription_response_marketplace import SubscriptionResponseMarketplace
from equinix.services.fabricv4.models.subscription_response_offer_type import SubscriptionResponseOfferType
from equinix.services.fabricv4.models.subscription_router_package_type import SubscriptionRouterPackageType
from equinix.services.fabricv4.models.subscription_router_package_type_code import SubscriptionRouterPackageTypeCode
from equinix.services.fabricv4.models.subscription_state import SubscriptionState
from equinix.services.fabricv4.models.subscription_trial import SubscriptionTrial
from equinix.services.fabricv4.models.time_service_filter import TimeServiceFilter
from equinix.services.fabricv4.models.time_service_filters import TimeServiceFilters
from equinix.services.fabricv4.models.time_service_or_filter import TimeServiceOrFilter
from equinix.services.fabricv4.models.time_service_price import TimeServicePrice
from equinix.services.fabricv4.models.time_service_price_connection import TimeServicePriceConnection
from equinix.services.fabricv4.models.time_service_price_connection_a_side import TimeServicePriceConnectionASide
from equinix.services.fabricv4.models.time_service_price_connection_access_point import TimeServicePriceConnectionAccessPoint
from equinix.services.fabricv4.models.time_service_simple_expression import TimeServiceSimpleExpression
from equinix.services.fabricv4.models.time_service_sort_by import TimeServiceSortBy
from equinix.services.fabricv4.models.time_service_sort_criteria import TimeServiceSortCriteria
from equinix.services.fabricv4.models.time_service_sort_direction import TimeServiceSortDirection
from equinix.services.fabricv4.models.time_services_search_request import TimeServicesSearchRequest
from equinix.services.fabricv4.models.top_utilized_statistics import TopUtilizedStatistics
from equinix.services.fabricv4.models.validate_connection_response import ValidateConnectionResponse
from equinix.services.fabricv4.models.validate_request import ValidateRequest
from equinix.services.fabricv4.models.validate_request_filter import ValidateRequestFilter
from equinix.services.fabricv4.models.validate_request_filter_and import ValidateRequestFilterAnd
from equinix.services.fabricv4.models.validate_subnet_response import ValidateSubnetResponse
from equinix.services.fabricv4.models.view_point import ViewPoint
from equinix.services.fabricv4.models.virtual_connection_bridge_package_code import VirtualConnectionBridgePackageCode
from equinix.services.fabricv4.models.virtual_connection_price import VirtualConnectionPrice
from equinix.services.fabricv4.models.virtual_connection_price_a_side import VirtualConnectionPriceASide
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point import VirtualConnectionPriceASideAccessPoint
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port import VirtualConnectionPriceASideAccessPointPort
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port_settings import VirtualConnectionPriceASideAccessPointPortSettings
from equinix.services.fabricv4.models.virtual_connection_price_access_point_type import VirtualConnectionPriceAccessPointType
from equinix.services.fabricv4.models.virtual_connection_price_connection_type import VirtualConnectionPriceConnectionType
from equinix.services.fabricv4.models.virtual_connection_price_z_side import VirtualConnectionPriceZSide
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point import VirtualConnectionPriceZSideAccessPoint
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_bridge import VirtualConnectionPriceZSideAccessPointBridge
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_bridge_package import VirtualConnectionPriceZSideAccessPointBridgePackage
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_profile import VirtualConnectionPriceZSideAccessPointProfile
from equinix.services.fabricv4.models.virtual_connection_side import VirtualConnectionSide
from equinix.services.fabricv4.models.virtual_connection_time_service_response import VirtualConnectionTimeServiceResponse
from equinix.services.fabricv4.models.virtual_connection_uuid import VirtualConnectionUuid
from equinix.services.fabricv4.models.virtual_device import VirtualDevice
from equinix.services.fabricv4.models.virtual_device_interface import VirtualDeviceInterface
from equinix.services.fabricv4.models.virtual_device_interface_type import VirtualDeviceInterfaceType
from equinix.services.fabricv4.models.virtual_device_type import VirtualDeviceType
from equinix.services.fabricv4.models.virtual_network import VirtualNetwork
from equinix.services.fabricv4.models.virtual_port_configuration import VirtualPortConfiguration
from equinix.services.fabricv4.models.virtual_port_location import VirtualPortLocation
from equinix.services.fabricv4.models.virtual_port_price import VirtualPortPrice
from equinix.services.fabricv4.models.virtual_port_redundancy import VirtualPortRedundancy
from equinix.services.fabricv4.models.virtual_port_service_type import VirtualPortServiceType
from equinix.services.fabricv4.models.virtual_port_type import VirtualPortType
from equinix.services.fabricv4.models.vpic_interface import VpicInterface



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.href import Href
from typing import Optional, Set
from typing_extensions import Self

class BgpSession(BaseModel):
    """
    BgpSession
    """ # noqa: E501
    address_family: StrictStr
    created_at: Optional[datetime] = None
    default_route: Optional[StrictBool] = None
    device: Optional[Href] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    learned_routes: Optional[List[StrictStr]] = None
    status: Optional[StrictStr] = Field(default=None, description=" The status of the BGP Session. Multiple status values may be reported when the device is connected to multiple switches, one value per switch. Each status will start with \"unknown\" and progress to \"up\" or \"down\" depending on the connected device. Subsequent \"unknown\" values indicate a problem acquiring status from the switch. ")
    updated_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["address_family", "created_at", "default_route", "device", "href", "id", "learned_routes", "status", "updated_at"]

    @field_validator('address_family')
    def address_family_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ipv4', 'ipv6']):
            raise ValueError("must be one of enum values ('ipv4', 'ipv6')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BgpSession from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of device
        if self.device:
            _dict['device'] = self.device.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BgpSession from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address_family": obj.get("address_family"),
            "created_at": obj.get("created_at"),
            "default_route": obj.get("default_route"),
            "device": Href.from_dict(obj["device"]) if obj.get("device") is not None else None,
            "href": obj.get("href"),
            "id": obj.get("id"),
            "learned_routes": obj.get("learned_routes"),
            "status": obj.get("status"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from equinix.services.fabricv4.models.add_operation import AddOperation
from equinix.services.fabricv4.models.remove_operation import RemoveOperation
from equinix.services.fabricv4.models.replace_operation import ReplaceOperation
from pydantic import StrictStr, Field
from typing import Union, List, Optional, Dict
from typing_extensions import Literal, Self

JSONPATCHOPERATION_ONE_OF_SCHEMAS = ["AddOperation", "RemoveOperation", "ReplaceOperation"]

class JsonPatchOperation(BaseModel):
    """
    Service Profile Access Points
    """
    # data type: AddOperation
    oneof_schema_1_validator: Optional[AddOperation] = None
    # data type: RemoveOperation
    oneof_schema_2_validator: Optional[RemoveOperation] = None
    # data type: ReplaceOperation
    oneof_schema_3_validator: Optional[ReplaceOperation] = None
    actual_instance: Optional[Union[AddOperation, RemoveOperation, ReplaceOperation]] = None
    one_of_schemas: List[str] = Field(default=Literal["AddOperation", "RemoveOperation", "ReplaceOperation"])

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = JsonPatchOperation.model_construct()
        error_messages = []
        match = 0
        # validate data type: AddOperation
        if not isinstance(v, AddOperation):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AddOperation`")
        else:
            match += 1
        # validate data type: RemoveOperation
        if not isinstance(v, RemoveOperation):
            error_messages.append(f"Error! Input type `{type(v)}` is not `RemoveOperation`")
        else:
            match += 1
        # validate data type: ReplaceOperation
        if not isinstance(v, ReplaceOperation):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ReplaceOperation`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in JsonPatchOperation with oneOf schemas: AddOperation, RemoveOperation, ReplaceOperation. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in JsonPatchOperation with oneOf schemas: AddOperation, RemoveOperation, ReplaceOperation. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AddOperation
        try:
            instance.actual_instance = AddOperation.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into RemoveOperation
        try:
            instance.actual_instance = RemoveOperation.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ReplaceOperation
        try:
            instance.actual_instance = ReplaceOperation.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into JsonPatchOperation with oneOf schemas: AddOperation, RemoveOperation, ReplaceOperation. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into JsonPatchOperation with oneOf schemas: AddOperation, RemoveOperation, ReplaceOperation. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AddOperation, RemoveOperation, ReplaceOperation]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.capacity_api import CapacityApi


class TestCapacityApi(unittest.TestCase):
    """CapacityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CapacityApi()

    def tearDown(self) -> None:
        pass

    def test_check_capacity_for_facility(self) -> None:
        """Test case for check_capacity_for_facility

        Check capacity
        """
        pass

    def test_check_capacity_for_metro(self) -> None:
        """Test case for check_capacity_for_metro

        Check capacity for a metro
        """
        pass

    def test_find_capacity_for_facility(self) -> None:
        """Test case for find_capacity_for_facility

        View capacity
        """
        pass

    def test_find_capacity_for_metro(self) -> None:
        """Test case for find_capacity_for_metro

        View capacity for metros
        """
        pass

    def test_find_organization_capacity_per_facility(self) -> None:
        """Test case for find_organization_capacity_per_facility

        View available hardware plans per Facility for given organization
        """
        pass

    def test_find_organization_capacity_per_metro(self) -> None:
        """Test case for find_organization_capacity_per_metro

        View available hardware plans per Metro for given organization
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class VrfVirtualCircuitCreateInput(BaseModel):
    """
    VrfVirtualCircuitCreateInput
    """ # noqa: E501
    customer_ip: Optional[StrictStr] = Field(default=None, description="An IPv4 address from the subnet that will be used on the Customer side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet as the Metal IP. By default, the last usable IP address in the subnet will be used.")
    customer_ipv6: Optional[StrictStr] = Field(default=None, description="An IPv6 address from the subnet IPv6 that will be used on the Customer side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet IPv6 as the Metal IPv6. By default, the last usable IP address in the subnet IPv6 will be used.")
    description: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    md5: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="The plaintext BGP peering password shared by neighbors as an MD5 checksum: * must be 10-20 characters long * may not include punctuation * must be a combination of numbers and letters * must contain at least one lowercase, uppercase, and digit character ")
    metal_ip: Optional[StrictStr] = Field(default=None, description="An IPv4 address from the subnet that will be used on the Metal side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet as the Customer IP. By default, the first usable IP address in the subnet will be used.")
    metal_ipv6: Optional[StrictStr] = Field(default=None, description="An IPv6 address from the subnet IPv6 that will be used on the Metal side. This parameter is optional, but if supplied, we will use the other usable IPv6 address in the subnet IPv6 as the Customer IP. By default, the first usable IPv6 address in the subnet IPv6 will be used.")
    name: Optional[StrictStr] = None
    nni_vlan: Annotated[int, Field(le=4094, strict=True, ge=2)]
    peer_asn: Annotated[int, Field(le=4294967295, strict=True, ge=0)] = Field(description="The peer ASN that will be used with the VRF on the Virtual Circuit.")
    project_id: StrictStr
    speed: Optional[StrictStr] = Field(default=None, description="speed can be passed as integer number representing bps speed or string (e.g. '52m' or '100g' or '4 gbps')")
    subnet: StrictStr = Field(description="The /30 or /31 IPv4 subnet of one of the VRF IP Blocks that will be used with the VRF for the Virtual Circuit. This subnet does not have to be an existing VRF IP reservation, as we will create the VRF IP reservation on creation if it does not exist. The Metal IP and Customer IP must be IPs from this subnet. For /30 subnets, the network and broadcast IPs cannot be used as the Metal or Customer IP. The subnet specified must be contained within an already-defined IP Range for the VRF.")
    subnet_ipv6: Optional[StrictStr] = Field(default=None, description="The /126 or /127 IPv6 subnet of one of the VRF IP Blocks that will be used with the VRF for the Virtual Circuit. This subnet does not have to be an existing VRF IP reservation, as we will create the VRF IP reservation on creation if it does not exist. The Metal IPv6 and Customer IPv6 must be IPs from this subnet. For /126 subnets, the network and broadcast IPs cannot be used as the Metal IPv6 or Customer IPv6. The subnet specified must be contained within an already-defined IP Range for the VRF.")
    tags: Optional[List[StrictStr]] = None
    vrf: StrictStr = Field(description="The UUID of the VRF that will be associated with the Virtual Circuit.")
    __properties: ClassVar[List[str]] = ["customer_ip", "customer_ipv6", "description", "href", "md5", "metal_ip", "metal_ipv6", "name", "nni_vlan", "peer_asn", "project_id", "speed", "subnet", "subnet_ipv6", "tags", "vrf"]

    @field_validator('md5')
    def md5_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d]{10,20}$", value):
            raise ValueError(r"must validate the regular expression /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d]{10,20}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VrfVirtualCircuitCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if md5 (nullable) is None
        # and model_fields_set contains the field
        if self.md5 is None and "md5" in self.model_fields_set:
            _dict['md5'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VrfVirtualCircuitCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customer_ip": obj.get("customer_ip"),
            "customer_ipv6": obj.get("customer_ipv6"),
            "description": obj.get("description"),
            "href": obj.get("href"),
            "md5": obj.get("md5"),
            "metal_ip": obj.get("metal_ip"),
            "metal_ipv6": obj.get("metal_ipv6"),
            "name": obj.get("name"),
            "nni_vlan": obj.get("nni_vlan"),
            "peer_asn": obj.get("peer_asn"),
            "project_id": obj.get("project_id"),
            "speed": obj.get("speed"),
            "subnet": obj.get("subnet"),
            "subnet_ipv6": obj.get("subnet_ipv6"),
            "tags": obj.get("tags"),
            "vrf": obj.get("vrf")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.service_profile_access_point_type import ServiceProfileAccessPointType

class TestServiceProfileAccessPointType(unittest.TestCase):
    """ServiceProfileAccessPointType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceProfileAccessPointType:
        """Test ServiceProfileAccessPointType
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceProfileAccessPointType`
        """
        model = ServiceProfileAccessPointType()
        if include_optional:
            return ServiceProfileAccessPointType(
                uuid = '',
                type = 'VD',
                supported_bandwidths = [
                    50
                    ],
                allow_remote_connections = True,
                allow_custom_bandwidth = True,
                bandwidth_alert_threshold = 1.337,
                allow_bandwidth_auto_approval = True,
                allow_bandwidth_upgrade = True,
                link_protocol_config = equinix.services.fabricv4.models.service_profile_link_protocol_config.ServiceProfileLinkProtocolConfig(
                    encapsulation_strategy = 'CTAGED', 
                    named_tags = [
                        ''
                        ], 
                    vlan_c_tag_label = '', 
                    reuse_vlan_s_tag = True, 
                    encapsulation = 'QINQ', ),
                enable_auto_generate_service_key = True,
                connection_redundancy_required = True,
                api_config = equinix.services.fabricv4.models.api_config.ApiConfig(
                    api_available = True, 
                    integration_id = '', 
                    equinix_managed_port = True, 
                    equinix_managed_vlan = True, 
                    allow_over_subscription = False, 
                    over_subscription_limit = 1, 
                    bandwidth_from_api = True, ),
                connection_label = '',
                authentication_key = equinix.services.fabricv4.models.authentication_key.AuthenticationKey(
                    required = True, 
                    label = 'Service Key', 
                    description = 'description for the authentication key', ),
                metadata = equinix.services.fabricv4.models.service_profile_metadata.ServiceProfileMetadata(
                    props = '', 
                    reg_ex = '', 
                    reg_ex_msg = '', 
                    vlan_range_max_value = 56, 
                    vlan_range_min_value = 56, 
                    max_qinq = '', 
                    max_dot1q = 56, 
                    variable_billing = True, 
                    global_organization = '', 
                    limit_auth_key_conn = True, 
                    allow_secondary_location = True, 
                    redundant_profile_id = '', 
                    allow_vc_migration = True, 
                    connection_editable = True, 
                    release_vlan = True, 
                    max_connections_on_port = 56, 
                    port_assignment_strategy = '', 
                    eqx_managed_port = True, 
                    connection_name_editable = True, )
            )
        else:
            return ServiceProfileAccessPointType(
                type = 'VD',
        )
        """

    def testServiceProfileAccessPointType(self):
        """Test ServiceProfileAccessPointType"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
